# About

This is intended as a small test project to experiment with Textual and creating an intuitive keyboard-centric dual pane filemanager. I'm tired of using windows directories and want to just be using something that I know how to customize.  
